@@ -15,13 +15,13 @@ if (1) {
   ## we will use an example dataset from PRIDE (dataset 2 of the PTXQC publication)
   local_zip = tempfile(fileext=".zip")
   tryCatch({
-	download.file("ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2015/11/PXD003133/txt_20min.zip", destfile = local_zip)
+    download.file("ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2015/11/PXD003133/txt_20min.zip", destfile = local_zip)
   }, error = function(err) {
     ## on Windows, one can get a 'cannot open URL' using the default method. So we try another
-	download.file("ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2015/11/PXD003133/txt_20min.zip", destfile = local_zip, method= "internal")
+    download.file("ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2015/11/PXD003133/txt_20min.zip", destfile = local_zip, method= "internal")
   })
   unzip(local_zip, exdir = tempdir()) ## extracts content
-  txt_folder = paste0(tempdir(),"/txt_20min")
+  txt_folder = file.path(tempdir(), "txt_20min")
 } else {
   ## if you have local MaxQuant output, just use it
   txt_folder = "c:/Proteomics/MouseLiver/combined/txt"
@@ -51,7 +51,7 @@ cat(paste0("\nReport generated as '", r$report_file, "'\n\n"))
 #    local_zip = tempfile(fileext=".zip")
 #    download.file("ftp://ftp.pride.ebi.ac.uk/pride/data/archive/2015/11/PXD003133/txt_20min.zip", destfile = local_zip)
 #    unzip(local_zip, exdir = tempdir()) ## extracts content
-#    txt_folder = paste0(tempdir(),"/txt_20min")
+#    txt_folder = file.path(tempdir(), "txt_20min")
 #  } else {
 #    ## if you have local MaxQuant output, just use it
 #    txt_folder = "c:/Proteomics/MouseLiver/combined/txt"
